==> ui-react-1.1.461.tgz: package/esm/SectionAction/SectionAction.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["size", "text", "link", "to", "ButtonProps", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { useNavigate } from 'react-router-dom';
import { is, isEnvironment } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import SectionElement from '../Section/Section';
import ButtonElement from '../Button';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'amaui-SectionAction'
});
const Element = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiSectionAction?.props?.default), props_), [props_]);
  const Section = React.useMemo(() => theme?.elements?.Section || SectionElement, [theme]);
  const Button = React.useMemo(() => theme?.elements?.Button || ButtonElement, [theme]);
  const {
      size = 'regular',
      text,
      link,
      to,
      ButtonProps,
      className
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const navigate = isEnvironment('browser') && useNavigate();
  const refs = {
    root: React.useRef()
  };
  return /*#__PURE__*/React.createElement(Section, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    className: classNames([staticClassName('SectionAction', theme) && ['amaui-SectionAction-root', `amaui-SectionAction-size-${size}`], className, classes.root])
  }, other), /*#__PURE__*/React.createElement(Button, _extends({
    tonal: true,
    version: "filled",
    size: size === 'large' ? 'regular' : size === 'regular' ? 'small' : 'small',
    onClick: to || link ? () => to ? navigate(to) : window.open(link, 'blank') : undefined
  }, ButtonProps, {
    className: classNames([staticClassName('SectionAction', theme) && ['amaui-SectionAction-item-button'], ButtonProps?.className, classes.button])
  }), text || 'Click here'));
});
Element.displayName = 'amaui-SectionAction';
export default Element;

==> ui-react-1.1.846.tgz: package/esm/SectionAction/SectionAction.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["size", "text", "link", "to", "ButtonProps", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { useNavigate } from 'react-router-dom';
import { is, isEnvironment } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import SectionElement from '../Section/Section';
import ButtonElement from '../Button';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'amaui-SectionAction'
});
const Element = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiSectionAction?.props?.default), props_), [props_]);
  const Section = React.useMemo(() => theme?.elements?.Section || SectionElement, [theme]);
  const Button = React.useMemo(() => theme?.elements?.Button || ButtonElement, [theme]);
  const {
      size = 'regular',
      text,
      link,
      to,
      ButtonProps,
      className
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const navigate = isEnvironment('browser') && useNavigate();
  const refs = {
    root: React.useRef(undefined)
  };
  return /*#__PURE__*/React.createElement(Section, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    className: classNames([staticClassName('SectionAction', theme) && ['amaui-SectionAction-root', `amaui-SectionAction-size-${size}`], className, classes.root])
  }, other), /*#__PURE__*/React.createElement(Button, _extends({
    tonal: true,
    version: "filled",
    size: size === 'large' ? 'regular' : size === 'regular' ? 'small' : 'small',
    onClick: to || link ? () => to ? navigate(to) : window.open(link, 'blank') : undefined
  }, ButtonProps, {
    className: classNames([staticClassName('SectionAction', theme) && ['amaui-SectionAction-item-button'], ButtonProps?.className, classes.button])
  }), text || 'Click here'));
});
Element.displayName = 'amaui-SectionAction';
export default Element;
